#!/bin/bash
rootfs_date=`date +%Y%m%d`
dists=`jq 'keys|length' lxc.json`
path=`pwd`

rm $path/aplinfo.dat ||true

for ((i=0;i<$dists;i++));
do
    dist=`jq keys[$i] lxc.json|sed "s/\"//g"`
    mkdir $path/$dist -p
    codenames=`jq ".$dist|keys|length" lxc.json`
    for ((n=0;n<$codenames;n++));
    do
        codename=`jq ".$dist[$n]" lxc.json|sed "s/\"//g"`
        echo $dist $codename;
        curl -o $path/$dist/$dist-$codename-"$rootfs_date"_arm64.tar.xz \
        "https://jenkins.linuxcontainers.org/view/LXC/job/image-$dist/architecture=arm64,release=$codename,variant=default/lastSuccessfulBuild/artifact/rootfs.tar.xz"
        md5=`md5sum $path/$dist/$dist-$codename-"$rootfs_date"_arm64.tar.xz|awk '{print $1}'`
        sha512sum=`sha512sum  $path/$dist/$dist-$codename-"$rootfs_date"_arm64.tar.xz|awk '{print $1}'`    
        # parse version
        version=$codename
        if [ $codename == "bookworm" ];then
                version="12"
        elif [ $codename == "bullseye" ];then
                version="11"
        elif [ $codename == "buster" ];then
                version="10"
        elif [ $codename == "sid" ];then
                version="$rootfs_date"
        elif [ $codename == "xenial" ];then
                version="16.04"
        elif [ $codename == "bionic" ];then
                version="18.04"
	elif [ $codename == "focal" ];then
                version="20.04"
        elif [ $codename == "jammy" ];then
                version="22.04"
        elif [ $codename == "lunar" ];then
                version="23.04"
        elif [ $codename == "mantic" ];then
                version="23.10"
        elif [ $codename == "sid" ];then
                version="$rootfs_date"
        elif [ $codename == "edge" ];then
                version="$rootfs_date"
        elif [ $codename == "current" ];then
                version="$rootfs_date"
        fi
        cat >>  $path/aplinfo.dat <<EOF
Package: $dist-$codename
Version: $version
Type: lxc
OS: $dist
Section: system
Certified: no
Maintainer: Linuxcontainers.org <https://lists.linuxcontainers.org/listinfo/lxc-devel>
Location: lxcs/$dist/$dist-$codename-"$rootfs_date"_arm64.tar.xz
Infopage: https://linuxcontainers.org
ManageUrl: https://mirrors.apqa.cn/proxmox/lxcs/build.sh
md5sum: $md5
sha512sum: $sha512sum
Description: $dist-$codename-arm64-$rootfs_date
  LXC default image for $dist.

EOF
    done;
done

gpg --detach-sign -a aplinfo.dat
gzip aplinfo.dat
